@@ -758,6 +758,17 @@ daq_request_channel(daq_t* daq, const char* name, enum chantype type,
 DLL_EXPORT int
 daq_request_channel_from_chanlist(daq_t* daq, daq_channel_t* channel);
 
+/**  Request a check on the data status for all channels added to the list 
+  *  for the specified interval. 
+  *  \brief Check requested data.
+  *  \param daq   Pointer to client status structure.
+  *  \param start GPS start time or 0 for online data.
+  *  \param end   GPS end time (see note for NDS1 protocol).
+  *  \return Server response code.
+  */
+DLL_EXPORT int
+daq_request_check(daq_t* daq, time_t start, time_t end);
+
 /**  Request data for all channels added to the list for the specified 
   *  interval and stride width. Data are received from the start time to 
   *  the end time in strides of \c dt seconds. An online data request is 
