@@ -129,6 +129,7 @@ int
 _daq_wait_data(nds_socket_type fd, int wt) {
     static const char* METHOD = "_daq_wait_data";
     int rc = -1;
+    int sv_errno = 0;
     int nfds =
 #if _WIN32
         1
@@ -150,6 +151,7 @@ _daq_wait_data(nds_socket_type fd, int wt) {
     while (rc < 0) {
         errno = 0;
         rc = select(nfds, &readfds, 0, 0, tptr);
+        sv_errno = errno;
 #if _WIN32
         if ( rc == SOCKET_ERROR )
         {
@@ -162,6 +164,7 @@ _daq_wait_data(nds_socket_type fd, int wt) {
                 nds_logging_print_errno( METHOD );
             }
             rc = -1;
+            errno = sv_errno;
             break;
         }
 #else /* _WIN32 */
@@ -174,17 +177,13 @@ _daq_wait_data(nds_socket_type fd, int wt) {
              */
             nds_logging_print_errno( METHOD );
         }
-        if (rc < 0 && errno != EINTR)
+        if (rc < 0 && sv_errno != EINTR)
         {
             break;
         }
 #endif /* _WIN32 */
     }
-    if (!rc) {
-        fprintf(stderr, "Timeout in _daq_wait_data\n");
-    } else if (rc < 0) {
-        perror("Error in _daq_wait_data()");
-    }
+    errno = sv_errno;
     return rc;
 }
 
@@ -203,7 +202,7 @@ read_bytes (nds_socket_type fd, char *cptr, size_t numb) {
         register const size_t        bytes_to_read = (numb-oread);
 #endif /* _WIN32 */
 
-        size_t bread = read (fd, cptr+oread, bytes_to_read);
+        ssize_t bread = read (fd, cptr+oread, bytes_to_read);
         if (bread > 0) {
             oread += (size_t) bread;
         } else if (!bread) {
@@ -220,7 +219,7 @@ read_bytes (nds_socket_type fd, char *cptr, size_t numb) {
                                     METHOD,
                                     pmsg );
             }
-            return 0;
+            return -1;
         }
     }
     /* printf("read(%i,...,%i) = %i\n", fd, numb,oread); */
@@ -232,9 +231,20 @@ read_bytes (nds_socket_type fd, char *cptr, size_t numb) {
 /* Return -1 for invalid response */
 long
 read_server_response_wait(nds_socket_type fd, int wt) {
-    if (wt > 0 && _daq_wait_data(fd, wt) <= 0) {
-        perror("read_server_response_wait: Error waiting for data");
-        return -1;
+    if (wt > 0) {
+        int rc;
+        rc = _daq_wait_data(fd, wt);
+        if (!rc) {
+            fprintf(stderr, "read_server_response_wait: Timed out\n");
+            errno = ETIME;
+            return -1;
+        } else if (rc < 0) {
+            int sv_errno;
+            sv_errno = errno;
+            perror("read_server_response_wait: Error waiting for response");
+            errno = sv_errno;
+            return -1;
+        }
     }
     return read_server_response(fd);
 }
@@ -245,7 +255,7 @@ read_server_response (nds_socket_type fd) {
     char buf [response_length + 1];
     int rc = read_bytes(fd, buf, (size_t)response_length);
     if (rc != response_length) {
-        if (rc < 0) perror("read_server_response: Error in read");
+        if (rc < 0 && errno) perror("read_server_response: Error in read");
         else fprintf(stderr, "read_server_response: Wrong length read (%i)\n",
                      rc);
         return -1;
