@@ -88,15 +88,20 @@
 /** Too many channels or too much data requested */
 #define DAQD_TOO_MANY_CHANNELS 0x0016
 
-/** Command syntax error */
-#define DAQD_COMMAND_SYNTAX 0x0017
+/** Requested feature is not supported */
+#define DAQD_NOT_SUPPORTED 0x0017
 
 /** Request sasl authentication protocol (nds2 only) */
 #define DAQD_SASL 0x0018
 
-/* IMPORTANT: leave NOT_SUPORTED msg the last */
-/** Requested feature is not supported */
-#define DAQD_NOT_SUPPORTED 0x0019
+/** Command syntax error */
+#define DAQD_COMMAND_SYNTAX 0x0019
+
+/** Requested data are on tape */
+#define DAQD_ONTAPE 0x001a
+
+/** No permission to access resource. */
+#define DAQD_ACCESS 0x001b
 
 /** \}
   */
