@@ -69,6 +69,12 @@ nds2_recv_source_list(daq_t *daq, char* list, size_t max_len,
 int
 nds2_disconnect (daq_t *daq);
 
+/*  nds2_request_check(daq_t*, time_t, time_t)
+ *
+ *  Check requested channel data status for the specified interval.
+ */
+int nds2_request_check(daq_t* daq, time_t start, time_t end);
+
 /*  nds2_request_data(daq_t*, time_t, time_t)
  *
  *  Get requested channel data for the specified interval.
