@@ -78,7 +78,7 @@ main( int ArgC, char** ArgV )
 
     sprintf( cmd, "%s --quiet-init-child", ArgV[0] );
     fcmd = popen( cmd, "r" );
-    while( fgets( output, sizeof( output ), fcmd ) )
+    while( fgets( output, (int)sizeof( output ), fcmd ) )
     {
       output_len += strlen( output );
     }
@@ -106,12 +106,12 @@ main( int ArgC, char** ArgV )
     fclose( fstderr );
 
     fstderr = fopen( filename, "r" );
-    bytes = fread( buffer, 1, sizeof( buffer ), fstderr );
+    bytes = fread( buffer, (size_t)1, sizeof( buffer ), fstderr );
     fclose( fstderr );
 
     if ( bytes )
     {
-      fwrite( buffer, 1, bytes, stdout );
+      fwrite( buffer, (size_t)1, bytes, stdout );
       fflush( stdout );
     }
 
