@@ -19,6 +19,7 @@
 
 #include "daqc.h"
 #include "daqc_internal.h"
+#include "daqc_response.h"
 #include "channel.h"
 #include "trench.h"
 
@@ -462,7 +463,7 @@ main(int argc, const char* argv[]) {
 				__FILE__ );
 	}
 	rc = daq_send(&daq, (char*)cmd);
-	printf("command sent, rc=%i\n", rc);
+	printf("command sent, rc=%i (%s)\n", rc, daq_strerror(rc));
 	break;
     }
 
@@ -752,6 +753,23 @@ main(int argc, const char* argv[]) {
 		return 2;
 	    }
 
+            /*   Check the data availability first */
+	    rc = daq_request_check(&daq, gps_start, gps_end);
+            if (rc == DAQD_ONTAPE) {
+                printf("Warning Data On Tape: %s\n", daq_strerror(rc));
+            } else if (rc == DAQD_COMMAND_SYNTAX || rc == DAQD_NOT_SUPPORTED ) {
+                printf("Warning: Can not check data availability: %s\n", 
+                       daq_strerror(rc));
+            } else if (rc != DAQD_OK) {
+                printf("Data not available - request ignored: %s\n", 
+                       daq_strerror(rc));
+                free(channel_list);
+                daq_disconnect(&daq);
+                daq_recv_shutdown(&daq);
+                return rc;
+            }
+
+            /*   Now get the data data */
 	    rc = daq_request_data(&daq, gps_start, gps_end, delta);
 	    if (rc) {
 		printf("Error in daq_request_data: %s\n", daq_strerror(rc));
