@@ -1509,6 +1509,12 @@ nds2_buffer **nds2_fetch(
 		result = daq_recv_next(&connection->daq);
 		if (result != DAQD_OK)
 		{
+			/* when we receive a 0 block we know we will not receive anything else and we will
+			 * either finish or error, so allow another transaction after this one.
+			 */
+			if (result == DAQD_NOT_FOUND) {
+				connection->request_in_progress = 0;
+			}
 			errno = NDS2_ELAST + result;
 			goto fail;
 		}
@@ -1772,6 +1778,12 @@ nds2_buffer **nds2_next(
 	result = daq_recv_next(&connection->daq);
 	if (result != DAQD_OK)
 	{
+		/* when we receive a 0 block we know we will not receive anything else and we will
+		 * either finish or error, so allow another transaction after this one.
+		 */
+		if (result == DAQD_NOT_FOUND) {
+			connection->request_in_progress = 0;
+		}
 		errno = NDS2_ELAST + result;
 		goto done;
 	}
